#!/bin/bash

# Convert a Metop CCSDS file to EPS Level 0 format (Metopizer 3.51.1 version)

# Check arguments
if [ $# -ne 2 ]; then
  echo "Usage: metop_ccsds_to_eps.bash ccsds_file sat_code"
  echo "where sat_code M02=Metop-A, M01=Metop-B, M03=Metop-C"
  exit 1
fi

# Set inputs
metop_file=$1
metop_code=$2

# Check input file size
file_size=$(stat -c %s $metop_file)
if [ $file_size -lt 25000000 ]; then
  echo "Input file is too small (< 25MB): "$metop_file
  exit 1
fi

# Create MPHR config file
echo "# MetOpizer L0 Production Configuration File
product_type=HRP
spacecraft_id=$metop_code
instrument_model=1
processing_centre=EARS
processing_mode=N
disposition_mode=O
processor_major_version=2
processor_minor_version=0
receiving_ground_station=GAN" > mphr.config

# Create config file for HKTM only
echo "# MetOpizer CCSDS APID configuration file
HKTM:      1-3,6" > ccsds_hktm.config

# Extract MMAM from HKTM
echo
echo "Extracting MMAM"
mkdir mmam
ccsds_to_l0 --config-apid ccsds_hktm.config --config-mphr mphr.config --generate-mmam mmam --in $metop_file --outdir $PWD

# Copy config file for all sensors
cp -v $METOPIZER_HOME/share/metopizer/ccsds.config $PWD

# Extract EPS Level 0 files and TLE (clock correction from MMAM will be applied)
ccsds_to_l0 --config-apid ccsds.config --config-mphr mphr.config --use-mmam mmam --generate-tle --in $metop_file --outdir $PWD/input 

# Move TLE file
mv TLE* input/tle.txt

exit 0
